@@ -33,9 +33,11 @@ def getCoursesTaken(html):
                 term = html_text[i+4]
             else:
                 term = html_text[i+5]
+            taken = False
             for course in courses:
                 if course.name == name:
-                    continue
-            courses.append(Course(name, term))
+                    taken = True
+            if not taken:
+            	courses.append(Course(name, term))
     return courses
     
